@@ -183,7 +183,7 @@ sub journalist {
             qr<（(中央社[记記]者 \S+ 日 專?[電电] | 大纪元记者\p{Letter}+报导 | 記者.+?報導/.+?)）>x,
             qr< \( ( \p{Letter}+ ／ \p{Letter}+ 報導 ) \) >x,
             qr<\A 文：記者(\p{Letter}+) \n>x,
-            qr<  （ (譯者：.+?/核稿：.+) ） \d+ \z >x,
+            qr<（ (譯者：.+?/核稿：.+?) ）[0-9]+(?:\n|\z)>x,
             qr< \(記者 (.+?) \) \z >x,
             qr<^(編譯[^／]+?／.+?報導)$>xsm,
             qr<（( (?:譯者|編輯)：.+) ） (?:[0-9]{7})? \z >x,
